<?php
/*
** Zabbix
** Copyright (C) 2001-2023 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/


// function add_audit($action, $resourcetype, $note) {
// 	if (mb_strlen($note) > 128) {
// 		$note = mb_substr($note, 0, 125).'...';
// 	}

// 	$values = [
// 		'userid' => CWebUser::$data['userid'],
// 		'clock' => time(),
// 		'ip' => substr(CWebUser::getIp(), 0, 39),
// 		'action' => $action,
// 		'resourcetype' => $resourcetype,
// 		'note' => $note
// 	];

// 	try {
// 		DB::insert('auditlog', [$values]);
// 		return true;
// 	}
// 	catch (DBException $e) {
// 		return false;
// 	}
// }

/**
 * Return associated list of available actions and labels.
 *
 * XXX:
 * This function is copied from ui/app/controllers/CControllerAuditLogList.php
 * because original function is private. It is possible to make difference from
 * original code. Be careful when maintenance the code.
 *
 * @return array
 */
function mlzbxGetActionsList(): array {
	return [
		CAudit::ACTION_LOGIN_SUCCESS => _('Login'),
		CAudit::ACTION_LOGIN_FAILED => _('Failed login'),
		CAudit::ACTION_LOGOUT => _('Logout'),
		CAudit::ACTION_ADD => _('Add'),
		CAudit::ACTION_UPDATE => _('Update'),
		CAudit::ACTION_DELETE => _('Delete'),
		CAudit::ACTION_EXECUTE => _('Execute'),
		CAudit::ACTION_HISTORY_CLEAR => _('History clear')
	];
}

/**
 * Return associated list of available resources and labels.
 *
 * XXX:
 * This function is copied from ui/app/controllers/CControllerAuditLogList.php
 * because original function is private. It is possible to make difference from
 * original code. Be careful when maintenance the code.
 *
 * @return array
 */
function mlzbxGetResourcesList(): array {
	return [
		CAudit::RESOURCE_ACTION => _('Action'),
		CAudit::RESOURCE_AUTH_TOKEN => _('API token'),
		CAudit::RESOURCE_AUTHENTICATION => _('Authentication'),
		CAudit::RESOURCE_AUTOREGISTRATION  => _('Autoregistration'),
		CAudit::RESOURCE_CORRELATION => _('Event correlation'),
		CAudit::RESOURCE_DASHBOARD => _('Dashboard'),
		CAudit::RESOURCE_DISCOVERY_RULE => _('Discovery rule'),
		CAudit::RESOURCE_GRAPH => _('Graph'),
		CAudit::RESOURCE_GRAPH_PROTOTYPE => _('Graph prototype'),
		CAudit::RESOURCE_HA_NODE => _('High availability node'),
		CAudit::RESOURCE_HOST => _('Host'),
		CAudit::RESOURCE_HOST_GROUP => _('Host group'),
		CAudit::RESOURCE_HOST_PROTOTYPE => _('Host prototype'),
		CAudit::RESOURCE_HOUSEKEEPING => _('Housekeeping'),
		CAudit::RESOURCE_ICON_MAP => _('Icon mapping'),
		CAudit::RESOURCE_IMAGE => _('Image'),
		CAudit::RESOURCE_IT_SERVICE => _('Service'),
		CAudit::RESOURCE_ITEM => _('Item'),
		CAudit::RESOURCE_ITEM_PROTOTYPE => _('Item prototype'),
		CAudit::RESOURCE_MACRO => _('Macro'),
		CAudit::RESOURCE_MAINTENANCE => _('Maintenance'),
		CAudit::RESOURCE_MAP => _('Map'),
		CAudit::RESOURCE_MEDIA_TYPE => _('Media type'),
		CAudit::RESOURCE_MODULE => _('Module'),
		CAudit::RESOURCE_PROXY => _('Proxy'),
		CAudit::RESOURCE_REGEXP => _('Regular expression'),
		CAudit::RESOURCE_SCENARIO => _('Web scenario'),
		CAudit::RESOURCE_SCHEDULED_REPORT => _('Scheduled report'),
		CAudit::RESOURCE_SCRIPT => _('Script'),
		CAudit::RESOURCE_SETTINGS => _('Settings'),
		CAudit::RESOURCE_SLA => _('SLA'),
		CAudit::RESOURCE_TEMPLATE => _('Template'),
		CAudit::RESOURCE_TEMPLATE_DASHBOARD => _('Template dashboard'),
		CAudit::RESOURCE_TRIGGER => _('Trigger'),
		CAudit::RESOURCE_TRIGGER_PROTOTYPE => _('Trigger prototype'),
		CAudit::RESOURCE_USER => _('User'),
		CAudit::RESOURCE_USER_GROUP => _('User group'),
		CAudit::RESOURCE_USER_ROLE => _('User role'),
		CAudit::RESOURCE_VALUE_MAP => _('Value map')
	];
}

/**
 * Send each auditlogs to syslog. Wrapper of mlzbx_send_auditlog_to_syslog().
 *
 * Copyright (c) Cybertrust Japan Co.,Ltd.
 *
 * @param array $auditlogs    Array of auditlog generated in CAudit::log()
 */ 
function mlzbx_add_auditlogs($auditlogs) {
	foreach ($auditlogs as $auditlog) {
		mlzbx_send_auditlog_to_syslog($auditlog);
	}
}

/**
 * Send auditlog to syslog.
 *
 * Copyright (c)  Cybertrust Japan Co.,Ltd.
 *
 * structure of "$auditlog":
 *   - userid
 *   - username
 *   - clock
 *   - ip
 *   - action
 *   - resourcetype
 *   - resourceid
 *   - resourcename
 *   - recordsetid
 *   - details
 *
 * @param array $auditlog    auditlog generated in CAudit::log()
 */ 
function mlzbx_send_auditlog_to_syslog($auditlog) {
	global $AUDITLOG_SYSLOG;
	if (!isset($AUDITLOG_SYSLOG)) {
		return;
	}

	$resourceslist = mlzbxGetResourcesList();
	$resource = isset($resourceslist[$auditlog['resourcetype']]) ? $resourceslist[$auditlog['resourcetype']] : 'Unknown resource';
	$actionslist = mlzbxGetActionsList();
	$action = isset($actionslist[$auditlog['action']]) ? $actionslist[$auditlog['action']] : 'Unknown action';

	$message = "Time={$auditlog['clock']} User={$auditlog['userid']} " .
		"IP={$auditlog['ip']} Resource={$resource} " .
		"Action={$action} ID={$auditlog['resourceid']} " .
		"Description={$auditlog['resourcename']} Details={$auditlog['details']}";

	$facility = isset($AUDITLOG_SYSLOG['FACILITY']) ? $AUDITLOG_SYSLOG['FACILITY'] : LOG_USER;
	$priority = isset($AUDITLOG_SYSLOG['PRIORITY']) ? $AUDITLOG_SYSLOG['PRIORITY'] : LOG_INFO;

	openlog('zabbix_web', LOG_PID, $facility);
	syslog($priority, $message);
	closelog();
}
